# Parse the workloads file for the different experiments and store in ARGS.
function parse_workloads {
    ARGS=()
    local exp_id=0
    echo "Parsed experiments:"

    # Read workloads file and parse variables.
    while IFS=" ", read -r nx ny nsteps; do
        # Test for empty variables.
        if [ -z "$nx" ] || [ -z "$ny" ] || [ -z "$nsteps" ]; then
            fatal "workloads.txt contains setup with missing variable:  '[$exp_id] $nx $ny $nsteps'"
            exit $?
        fi

        # Test that all variables consist of only numericals.
        local re="^[0-9]+$"
        if ! [[ $nx =~ $re ]] || ! [[ $ny =~ $re ]] || ! [[ $nsteps =~ $re ]]; then
            fatal "workloads.txt contains a non-numeric:  '[$exp_id] $nx $ny $nsteps'"
            exit $?
        fi

        # Print parsed workload, store in array, and increment counter.
        echo -e "\t[$exp_id] nx: $nx, ny: $ny, nsteps: $nsteps"
        ARGS+=("$nx" "$ny" "$nsteps")
        exp_id=$((exp_id + 1))
    done <<< $(tail -n +3 workloads.txt)
}

function profile {
    echo "ARGS:  ${ARGS[*]}"

    for ((i=0; i<${#ARGS[@]}; i=i+3)); do
        echo -e "nx: ${ARGS[$i]}, ny: ${ARGS[$i+1]}, nsteps: ${ARGS[$i+2]}"
    done

}

parse_workloads

profile
